summaryrefslogtreecommitdiffstats
path: root/src/vim9expr.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/vim9expr.c')
-rw-r--r--src/vim9expr.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/vim9expr.c b/src/vim9expr.c
index 6a1faf839f..1e87b8eae1 100644
--- a/src/vim9expr.c
+++ b/src/vim9expr.c
@@ -1883,7 +1883,7 @@ compile_subscript(
* trailing ->name() method call
*/
static int
-compile_expr7(
+compile_expr8(
char_u **arg,
cctx_T *cctx,
ppconst_T *ppconst)
@@ -2119,10 +2119,10 @@ compile_expr7(
}
/*
* <type>expr7: runtime type check / conversion
*/
static int
-compile_expr7t(char_u **arg, cctx_T *cctx, ppconst_T *ppconst)
+compile_expr7(char_u **arg, cctx_T *cctx, ppconst_T *ppconst)
{
type_T *want_type = NULL;
@@ -2147,7 +2147,7 @@ compile_expr7t(char_u **arg, cctx_T *cctx, ppconst_T *ppconst)
return FAIL;
}
- if (compile_expr7(arg, cctx, ppconst) == FAIL)
+ if (compile_expr8(arg, cctx, ppconst) == FAIL)
return FAIL;
if (want_type != NULL)
@@ -2182,7 +2182,7 @@ compile_expr6(char_u **arg, cctx_T *cctx, ppconst_T *ppconst)
int ppconst_used = ppconst->pp_used;
// get the first expression
- if (compile_expr7t(arg, cctx, ppconst) == FAIL)
+ if (compile_expr7(arg, cctx, ppconst) == FAIL)
return FAIL;
/*
@@ -2208,7 +2208,7 @@ compile_expr6(char_u **arg, cctx_T *cctx, ppconst_T *ppconst)
return FAIL;
// get the second expression
- if (compile_expr7t(arg, cctx, ppconst) == FAIL)
+ if (compile_expr7(arg, cctx, ppconst) == FAIL)
return FAIL;
if (ppconst->pp_used == ppconst_used + 2
@@ -2119,10 +2119,10 @@ compile_expr7(
}
/*
- * <type>expr7: runtime type check / conversion
+ * <type>expr8: runtime type check / conversion
*/
static int